#
# spec file for package python-sphinxcontrib-devhelp
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
%{?sle15_python_module_pythons}
Name:           python-sphinxcontrib-devhelp%{psuffix}
Version:        1.0.6
Release:        2.2
Summary:        Sphinx extension which outputs Devhelp documents
License:        BSD-2-Clause
Group:          Development/Languages/Python
URL:            https://github.com/sphinx-doc/sphinxcontrib-devhelp
Source0:        https://files.pythonhosted.org/packages/source/s/sphinxcontrib-devhelp/sphinxcontrib_devhelp-%{version}.tar.gz
Source99:       python-sphinxcontrib-devhelp.rpmlintrc
# PATCH-FIX-UPSTREAM no-store-btime-gzip.patch bsc#1227999 mcepl@suse.com
# don't store build time in gzip headers to make building documentation reproducible
Patch0:         no-store-btime-gzip.patch
%if %{with test}
BuildRequires:  %{python_module Sphinx >= 5.0}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module sphinxcontrib-devhelp >= %{version}}
%endif
BuildRequires:  %{python_module flit-core}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
sphinxcontrib-devhelp is a sphinx extension which outputs Devhelp document.

%prep
%autosetup -p1 -n sphinxcontrib_devhelp-%{version}

%build
%pyproject_wheel

%install
%if %{without test}
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%if %{with test}
%check
%pytest
%endif

%if %{without test}
%files %{python_files}
%doc README.rst CHANGES
%license LICENSE
%dir %{python_sitelib}/sphinxcontrib
%{python_sitelib}/sphinxcontrib/devhelp
%{python_sitelib}/sphinxcontrib_devhelp-%{version}*-info
%endif

%changelog
* Fri Jul 19 2024 Matej Cepl <mcepl@cepl.eu>
- Add no-store-btime-gzip.patch to fix bsc#1227999 by not storing
  build time in gzip headers so as to make building documentation
  reproducible
- Add rpmlintrc
* Sun Jan 14 2024 Dirk Müller <dmueller@suse.com>
- update to 1.0.6:
  * Remove Sphinx as a required dependency, as circular
    dependencies may cause failure with package managers that
    expect a directed acyclic graph (DAG) of dependencies.
* Thu Sep  7 2023 Dirk Müller <dmueller@suse.com>
- update to 1.0.5:
  * Use ``os.PathLike`` over ``pathlib.Path``
  * Fix tests for Sphinx 7.1 and below
  * Drop support for Python 3.5, 3.6, 3.7, and 3.8
  * Raise minimum required Sphinx version to 5.0
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Fri Mar  6 2020 pgajdos@suse.com
- version update to 1.0.2
  * Fix package metadata
* Tue Jun  4 2019 Tomáš Chvátal <tchvatal@suse.com>
- Initial commit, needed by Sphinx
